@@ -5,7 +5,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3 ./Parser/asdl_c.py',
+ 'ASDLGEN': 'python3.6 ./Parser/asdl_c.py',
  'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
  'AST_ASDL': './Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
@@ -562,8 +562,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETS_H': '\\',
  'OPCODE_H': './Include/opcode.h',
  'OPCODE_H_DIR': './Include',
- 'OPCODE_H_GEN': 'python3 ./Tools/scripts/generate_opcode_h.py ./Lib/opcode.py '
-                 './Include/opcode.h',
+ 'OPCODE_H_GEN': 'python3.6 ./Tools/scripts/generate_opcode_h.py '
+                 './Lib/opcode.py ./Include/opcode.h',
  'OPCODE_H_SCRIPT': './Tools/scripts/generate_opcode_h.py',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
@@ -595,7 +595,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_GEN': 'python3',
+ 'PYTHON_FOR_GEN': 'python3.6',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
